@@ -1,39 +1,29 @@
-/* This file is part of the KDE project
-   Copyright (C) 2005 Hamish Rodda <rodda@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2005 Hamish Rodda <rodda@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "codecompletiontestmodel.h"
 
-#include <ktexteditor/view.h>
-#include <ktexteditor/document.h>
-#include <ktexteditor/codecompletioninterface.h>
 #include <kateglobal.h>
 #include <katewordcompletion.h>
+#include <ktexteditor/codecompletioninterface.h>
+#include <ktexteditor/document.h>
+#include <ktexteditor/view.h>
 
 CodeCompletionTestModel::CodeCompletionTestModel(KTextEditor::View *parent, const QString &startText)
-    : KTextEditor::CodeCompletionModel(parent), m_startText(startText), m_autoStartText(m_startText.isEmpty())
+    : KTextEditor::CodeCompletionModel(parent)
+    , m_startText(startText)
+    , m_autoStartText(m_startText.isEmpty())
 {
     setRowCount(40);
 
     Q_ASSERT(cc());
 
     cc()->setAutomaticInvocationEnabled(true);
-    cc()->unregisterCompletionModel(KTextEditor::EditorPrivate::self()->wordCompletionModel()); //would add additional items, we don't want that in tests
+    cc()->unregisterCompletionModel(KTextEditor::EditorPrivate::self()->wordCompletionModel()); // would add additional items, we don't want that in tests
     cc()->registerCompletionModel(this);
 }
 
@@ -177,14 +167,20 @@ void CodeCompletionTestModel::completionInvoked(KTextEditor::View *view, const K
     qDebug() << m_startText;
 }
 
-AbbreviationCodeCompletionTestModel::AbbreviationCodeCompletionTestModel(KTextEditor::View *parent,
-        const QString &startText)
+AbbreviationCodeCompletionTestModel::AbbreviationCodeCompletionTestModel(KTextEditor::View *parent, const QString &startText)
     : CodeCompletionTestModel(parent, startText)
 {
-    m_items << "SomeCoolAbbreviation" << "someCoolAbbreviation" << "sca" << "SCA";
-    m_items << "some_cool_abbreviation" << "Some_Cool_Abbreviation";
-    m_items << "thisContainsSomeWord" << "this_contains_some_word" << "thiscontainssomeword";
-    m_items << "notmatchedbecausemissingcaps" << "not_m_atch_ed_because_underscores";
+    m_items << "SomeCoolAbbreviation"
+            << "someCoolAbbreviation"
+            << "sca"
+            << "SCA";
+    m_items << "some_cool_abbreviation"
+            << "Some_Cool_Abbreviation";
+    m_items << "thisContainsSomeWord"
+            << "this_contains_some_word"
+            << "thiscontainssomeword";
+    m_items << "notmatchedbecausemissingcaps"
+            << "not_m_atch_ed_because_underscores";
     setRowCount(m_items.size());
 }
 
@@ -195,4 +191,3 @@ QVariant AbbreviationCodeCompletionTestModel::data(const QModelIndex &index, int
     }
     return QVariant();
 }
-
