@@ -39,15 +39,16 @@ KateCompletionConfig::KateCompletionConfig(KateCompletionModel *model, QWidget *
     ui->sortingCaseSensitive->setChecked(m_model->sortingCaseSensitivity() == Qt::CaseSensitive);
     ui->groupingOrderUp->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     ui->groupingOrderDown->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-    connect(ui->groupingOrderUp, SIGNAL(pressed()), SLOT(moveGroupingOrderUp()));
-    connect(ui->groupingOrderDown, SIGNAL(pressed()), SLOT(moveGroupingOrderDown()));
+    connect(ui->groupingOrderUp, &QToolButton::pressed, this, &KateCompletionConfig::moveGroupingOrderUp);
+    connect(ui->groupingOrderDown, &QToolButton::pressed, this, &KateCompletionConfig::moveGroupingOrderDown);
 
     // Filtering
     ui->filtering->setChecked(m_model->isFilteringEnabled());
     ui->filteringContextMatchOnly->setChecked(m_model->filterContextMatchesOnly());
     ui->filteringHideAttributes->setChecked(m_model->filterByAttribute());
 
-    for (CodeCompletionModel::CompletionProperty i = CodeCompletionModel::FirstProperty; i <= CodeCompletionModel::LastProperty; i = static_cast<CodeCompletionModel::CompletionProperty>(i << 1)) {
+    for (CodeCompletionModel::CompletionProperty i = CodeCompletionModel::FirstProperty; i <= CodeCompletionModel::LastProperty;
+         i = static_cast<CodeCompletionModel::CompletionProperty>(i << 1)) {
         QListWidgetItem *item = new QListWidgetItem(m_model->propertyName(i), ui->filteringAttributesList, i);
         item->setCheckState((m_model->filterAttributes() & i) ? Qt::Checked : Qt::Unchecked);
     }
@@ -78,15 +79,15 @@ KateCompletionConfig::KateCompletionConfig(KateCompletionModel *model, QWidget *
     for (int i = 0; i < 4; ++i) {
         ui->groupingMethods->topLevelItem(i)->setCheckState(0, Qt::Unchecked);
     }
-    connect(ui->groupingUp, SIGNAL(pressed()), SLOT(moveGroupingUp()));
-    connect(ui->groupingDown, SIGNAL(pressed()), SLOT(moveGroupingDown()));
+    connect(ui->groupingUp, &QToolButton::pressed, this, &KateCompletionConfig::moveGroupingUp);
+    connect(ui->groupingDown, &QToolButton::pressed, this, &KateCompletionConfig::moveGroupingDown);
 
     // Column merging
     ui->columnMerging->setChecked(m_model->isColumnMergingEnabled());
     ui->columnUp->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
     ui->columnDown->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
-    connect(ui->columnUp, SIGNAL(pressed()), SLOT(moveColumnUp()));
-    connect(ui->columnDown, SIGNAL(pressed()), SLOT(moveColumnDown()));
+    connect(ui->columnUp, &QToolButton::pressed, this, &KateCompletionConfig::moveColumnUp);
+    connect(ui->columnDown, &QToolButton::pressed, this, &KateCompletionConfig::moveColumnDown);
 
     QList<int> mergedColumns;
     if (!m_model->columnMerges().isEmpty()) {
@@ -146,12 +147,12 @@ KateCompletionConfig::KateCompletionConfig(KateCompletionModel *model, QWidget *
     okButton->setDefault(true);
     KGuiItem::assign(okButton, KStandardGuiItem::ok());
     buttons->addButton(okButton, QDialogButtonBox::AcceptRole);
-    connect(okButton, SIGNAL(clicked()), this, SLOT(apply()));
+    connect(okButton, &QPushButton::clicked, this, &KateCompletionConfig::apply);
 
     QPushButton *cancelButton = new QPushButton(this);
     KGuiItem::assign(cancelButton, KStandardGuiItem::cancel());
     buttons->addButton(okButton, QDialogButtonBox::RejectRole);
-    connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
+    connect(cancelButton, &QPushButton::clicked, this, &KateCompletionConfig::reject);
 }
 
 KateCompletionConfig::~KateCompletionConfig()
@@ -206,7 +207,11 @@ void KateCompletionConfig::readConfig(const KConfigGroup &config)
     for (int i = 0; i < ui->columnMergeTree->topLevelItemCount(); ++i) {
         QTreeWidgetItem *item = ui->columnMergeTree->topLevelItem(i);
         /// Initialize a standard column-merging: Merge Scope, Name, Arguments and Postfix
-        item->setCheckState(1, config.readEntry(QStringLiteral("Column %1 Merge").arg(i), (i == CodeCompletionModel::Scope || i == CodeCompletionModel::Name || i == CodeCompletionModel::Arguments)) ? Qt::Checked : Qt::Unchecked);
+        item->setCheckState(1,
+                            config.readEntry(QStringLiteral("Column %1 Merge").arg(i),
+                                             (i == CodeCompletionModel::Scope || i == CodeCompletionModel::Name || i == CodeCompletionModel::Arguments))
+                                ? Qt::Checked
+                                : Qt::Unchecked);
         item->setCheckState(2, config.readEntry(QStringLiteral("Column %1 Show").arg(i), true) ? Qt::Checked : Qt::Unchecked);
     }
 
