@@ -10,6 +10,7 @@
 #include "kateconfig.h"
 #include "katedocument.h"
 #include "kateglobal.h"
+#include "katerenderer.h"
 #include "kateview.h"
 
 #include <ktexteditor/movingrange.h>
@@ -127,7 +128,10 @@ int KateWordCompletionModel::rowCount(const QModelIndex &parent) const
     }
 }
 
-bool KateWordCompletionModel::shouldStartCompletion(KTextEditor::View *view, const QString &insertedText, bool userInsertion, const KTextEditor::Cursor &position)
+bool KateWordCompletionModel::shouldStartCompletion(KTextEditor::View *view,
+                                                    const QString &insertedText,
+                                                    bool userInsertion,
+                                                    const KTextEditor::Cursor &position)
 {
     if (!userInsertion) {
         return false;
@@ -289,7 +293,6 @@ struct KateWordCompletionViewPrivate {
     KTextEditor::MovingRange *liRange; // range containing last inserted text
     KTextEditor::Range dcRange; // current range to be completed by directional completion
     KTextEditor::Cursor dcCursor; // directional completion search cursor
-    QRegularExpression wordRegEx;
     int directionalPos; // be able to insert "" at the correct time
     bool isCompleting; // true when the directional completion is doing a completion
 };
@@ -303,7 +306,8 @@ KateWordCompletionView::KateWordCompletionView(KTextEditor::View *view, KActionC
     d->isCompleting = false;
     d->dcRange = KTextEditor::Range::invalid();
 
-    d->liRange = static_cast<KTextEditor::DocumentPrivate *>(m_view->document())->newMovingRange(KTextEditor::Range::invalid(), KTextEditor::MovingRange::DoNotExpand);
+    d->liRange =
+        static_cast<KTextEditor::DocumentPrivate *>(m_view->document())->newMovingRange(KTextEditor::Range::invalid(), KTextEditor::MovingRange::DoNotExpand);
 
     KTextEditor::Attribute::Ptr a = KTextEditor::Attribute::Ptr(new KTextEditor::Attribute());
     a->setBackground(static_cast<KTextEditor::ViewPrivate *>(view)->renderer()->config()->selectionColor());
@@ -314,18 +318,18 @@ KateWordCompletionView::KateWordCompletionView(KTextEditor::View *view, KActionC
     if (qobject_cast<KTextEditor::CodeCompletionInterface *>(view)) {
         action = new QAction(i18n("Shell Completion"), this);
         ac->addAction(QStringLiteral("doccomplete_sh"), action);
-        connect(action, SIGNAL(triggered()), this, SLOT(shellComplete()));
+        connect(action, &QAction::triggered, this, &KateWordCompletionView::shellComplete);
     }
 
     action = new QAction(i18n("Reuse Word Above"), this);
     ac->addAction(QStringLiteral("doccomplete_bw"), action);
     ac->setDefaultShortcut(action, Qt::CTRL + Qt::Key_8);
-    connect(action, SIGNAL(triggered()), this, SLOT(completeBackwards()));
+    connect(action, &QAction::triggered, this, &KateWordCompletionView::completeBackwards);
 
     action = new QAction(i18n("Reuse Word Below"), this);
     ac->addAction(QStringLiteral("doccomplete_fw"), action);
     ac->setDefaultShortcut(action, Qt::CTRL + Qt::Key_9);
-    connect(action, SIGNAL(triggered()), this, SLOT(completeForwards()));
+    connect(action, &QAction::triggered, this, &KateWordCompletionView::completeForwards);
 }
 
 KateWordCompletionView::~KateWordCompletionView()
@@ -386,7 +390,7 @@ void KateWordCompletionView::shellComplete()
         m_view->document()->insertText(r.end(), partial.mid(r.columnWidth()));
         d->liRange->setView(m_view);
         d->liRange->setRange(KTextEditor::Range(r.end(), partial.length() - r.columnWidth()));
-        connect(m_view, SIGNAL(cursorPositionChanged(KTextEditor::View *, KTextEditor::Cursor)), this, SLOT(slotCursorMoved()));
+        connect(m_view, &KTextEditor::View::cursorPositionChanged, this, &KateWordCompletionView::slotCursorMoved);
     }
 }
 
@@ -432,17 +436,17 @@ void KateWordCompletionView::complete(bool fw)
 
         d->liRange->setView(m_view);
 
-        connect(m_view, SIGNAL(cursorPositionChanged(KTextEditor::View *, KTextEditor::Cursor)), this, SLOT(slotCursorMoved()));
+        connect(m_view, &KTextEditor::View::cursorPositionChanged, this, &KateWordCompletionView::slotCursorMoved);
     }
 
-    d->wordRegEx.setPattern(QLatin1String("\\b") + doc->text(d->dcRange) + QLatin1String("(\\w+)"));
+    const QRegularExpression wordRegEx(QLatin1String("\\b") + doc->text(d->dcRange) + QLatin1String("(\\w+)"), QRegularExpression::UseUnicodePropertiesOption);
     int pos(0);
     QString ln = doc->line(d->dcCursor.line());
 
     while (true) {
-        // qCDebug(LOG_KTE)<<"SEARCHING FOR "<<d->wordRegEx.pattern()<<" "<<ln<<" at "<<d->dcCursor;
+        // qCDebug(LOG_KTE)<<"SEARCHING FOR "<<wordRegEx.pattern()<<" "<<ln<<" at "<<d->dcCursor;
         QRegularExpressionMatch match;
-        pos = fw ? ln.indexOf(d->wordRegEx, d->dcCursor.column(), &match) : ln.lastIndexOf(d->wordRegEx, d->dcCursor.column(), &match);
+        pos = fw ? ln.indexOf(wordRegEx, d->dcCursor.column(), &match) : ln.lastIndexOf(wordRegEx, d->dcCursor.column(), &match);
 
         if (match.hasMatch()) { // we matched a word
             // qCDebug(LOG_KTE)<<"USABLE MATCH";
@@ -511,7 +515,7 @@ void KateWordCompletionView::slotCursorMoved()
 
     d->dcRange = KTextEditor::Range::invalid();
 
-    disconnect(m_view, SIGNAL(cursorPositionChanged(KTextEditor::View *, KTextEditor::Cursor)), this, SLOT(slotCursorMoved()));
+    disconnect(m_view, &KTextEditor::View::cursorPositionChanged, this, &KateWordCompletionView::slotCursorMoved);
 
     d->liRange->setView(nullptr);
     d->liRange->setRange(KTextEditor::Range::invalid());
