@@ -212,7 +212,10 @@ void KateRenderer::paintTextLineBackground(QPainter &paint, KateLineLayoutPtr la
         markRed /= markCount;
         markGreen /= markCount;
         markBlue /= markCount;
-        backgroundColor.setRgb(int((backgroundColor.red() * 0.9) + (markRed * 0.1)), int((backgroundColor.green() * 0.9) + (markGreen * 0.1)), int((backgroundColor.blue() * 0.9) + (markBlue * 0.1)));
+        backgroundColor.setRgb(int((backgroundColor.red() * 0.9) + (markRed * 0.1)),
+                               int((backgroundColor.green() * 0.9) + (markGreen * 0.1)),
+                               int((backgroundColor.blue() * 0.9) + (markBlue * 0.1)),
+                               backgroundColor.alpha());
     }
 
     // Draw line background
@@ -225,7 +228,10 @@ void KateRenderer::paintTextLineBackground(QPainter &paint, KateLineLayoutPtr la
             markRed /= markCount;
             markGreen /= markCount;
             markBlue /= markCount;
-            currentLineColor.setRgb(int((currentLineColor.red() * 0.9) + (markRed * 0.1)), int((currentLineColor.green() * 0.9) + (markGreen * 0.1)), int((currentLineColor.blue() * 0.9) + (markBlue * 0.1)));
+            currentLineColor.setRgb(int((currentLineColor.red() * 0.9) + (markRed * 0.1)),
+                                    int((currentLineColor.green() * 0.9) + (markGreen * 0.1)),
+                                    int((currentLineColor.blue() * 0.9) + (markBlue * 0.1)),
+                                    currentLineColor.alpha());
         }
 
         paint.fillRect(0, lineHeight() * currentViewLine, xEnd - xStart, lineHeight(), currentLineColor);
@@ -319,19 +325,12 @@ void KateRenderer::paintIndentMarker(QPainter &paint, uint x, uint y /*row*/)
     QPen myPen(config()->indentationLineColor());
     static const QVector<qreal> dashPattern = QVector<qreal>() << 1 << 1;
     myPen.setDashPattern(dashPattern);
-    if (y % 2) {
-        myPen.setDashOffset(1);
-    }
     paint.setPen(myPen);
 
-    const int height = fontHeight();
-    const int top = 0;
-    const int bottom = height - 1;
-
     QPainter::RenderHints renderHints = paint.renderHints();
     paint.setRenderHints(renderHints, false);
 
-    paint.drawLine(x + 2, top, x + 2, bottom);
+    paint.drawLine(x + 2, 0, x + 2, lineHeight());
 
     paint.setRenderHints(renderHints, true);
 
@@ -361,7 +360,8 @@ static bool rangeLessThanForRenderer(const Kate::TextRange *a, const Kate::TextR
     return false;
 }
 
-QVector<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool selectionsOnly, bool completionHighlight, bool completionSelected) const
+QVector<QTextLayout::FormatRange>
+KateRenderer::decorationsForLine(const Kate::TextLine &textLine, int line, bool selectionsOnly, bool completionHighlight, bool completionSelected) const
 {
     // limit number of attributes we can highlight in reasonable time
     const int limitOfRanges = 1024;
@@ -393,7 +393,8 @@ QVector<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::T
         const QSet<Kate::TextRange *> *rangesCaretIn = m_view ? m_view->rangesCaretIn() : nullptr;
         bool anyDynamicHlsActive = m_view && (!rangesMouseIn->empty() || !rangesCaretIn->empty());
 
-        // sort all ranges, we want that the most specific ranges win during rendering, multiple equal ranges are kind of random, still better than old smart rangs behavior ;)
+        // sort all ranges, we want that the most specific ranges win during rendering, multiple equal ranges are kind of random, still better than old smart
+        // rangs behavior ;)
         std::sort(rangesWithAttributes.begin(), rangesWithAttributes.end(), rangeLessThanForRenderer);
 
         // loop over all ranges
@@ -425,7 +426,8 @@ QVector<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::T
     }
 
     // Add selection highlighting if we're creating the selection decorations
-    if ((m_view && selectionsOnly && showSelections() && m_view->selection()) || (completionHighlight && completionSelected) || (m_view && m_view->blockSelection())) {
+    if ((m_view && selectionsOnly && showSelections() && m_view->selection()) || (completionHighlight && completionSelected)
+        || (m_view && m_view->blockSelection())) {
         auto &currentRange = renderRanges.pushNewRange();
 
         // Set up the selection background attribute TODO: move this elsewhere, eg. into the config?
@@ -492,8 +494,9 @@ QVector<QTextLayout::FormatRange> KateRenderer::decorationsForLine(const Kate::T
             fr.length = nextPosition.column() - currentPosition.column();
 
         } else {
-            // +1 to force background drawing at the end of the line when it's warranted
-            fr.length = textLine->length() - currentPosition.column() + 1;
+            // before we did here +1 to force background drawing at the end of the line when it's warranted
+            // we now skip this, we don't draw e.g. full line backgrounds
+            fr.length = textLine->length() - currentPosition.column();
         }
 
         KTextEditor::Attribute::Ptr a = renderRanges.generateAttribute();
@@ -551,7 +554,8 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
     }
 
     if (range->layout()) {
-        bool drawSelection = m_view && m_view->selection() && showSelections() && m_view->selectionRange().overlapsLine(range->line()) && !flags.testFlag(SkipDrawLineSelection);
+        bool drawSelection =
+            m_view && m_view->selection() && showSelections() && m_view->selectionRange().overlapsLine(range->line()) && !flags.testFlag(SkipDrawLineSelection);
         // Draw selection in block selection mode. We need 2 kinds of selections that QTextLayout::draw can't render:
         //   - past-end-of-line selection and
         //   - 0-column-wide selection (used to indicate where text will be typed)
@@ -564,7 +568,8 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
                 if (selectionEndColumn > lastLine.startCol()) {
                     int selectionStartX = (selectionStartColumn > lastLine.startCol()) ? cursorToX(lastLine, selectionStartColumn, true) : 0;
                     int selectionEndX = cursorToX(lastLine, selectionEndColumn, true);
-                    paint.fillRect(QRect(selectionStartX - xStart, (int)lastLine.lineLayout().y(), selectionEndX - selectionStartX, lineHeight()), selectionBrush);
+                    paint.fillRect(QRect(selectionStartX - xStart, (int)lastLine.lineLayout().y(), selectionEndX - selectionStartX, lineHeight()),
+                                   selectionBrush);
                 }
             } else {
                 const int selectStickWidth = 2;
@@ -590,92 +595,16 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
             }
         }
 
-        QBrush backgroundBrush;
-        bool backgroundBrushSet = false;
-
         // Loop each individual line for additional text decoration etc.
-        QVectorIterator<QTextLayout::FormatRange> it = range->layout()->formats();
-        QVectorIterator<QTextLayout::FormatRange> it2 = additionalFormats;
         for (int i = 0; i < range->viewLineCount(); ++i) {
             KateTextLayout line = range->viewLine(i);
 
-            bool haveBackground = false;
-            // Determine the background to use, if any, for the end of this view line
-            backgroundBrushSet = false;
-            while (it2.hasNext()) {
-                const QTextLayout::FormatRange &fr = it2.peekNext();
-                if (fr.start > line.endCol()) {
-                    break;
-                }
-
-                if (fr.start + fr.length > line.endCol()) {
-                    if (fr.format.hasProperty(QTextFormat::BackgroundBrush)) {
-                        backgroundBrushSet = true;
-                        backgroundBrush = fr.format.background();
-                    }
-
-                    haveBackground = true;
-                    break;
-                }
-
-                it2.next();
-            }
-
-            while (!haveBackground && it.hasNext()) {
-                const QTextLayout::FormatRange &fr = it.peekNext();
-                if (fr.start > line.endCol()) {
-                    break;
-                }
-
-                if (fr.start + fr.length > line.endCol()) {
-                    if (fr.format.hasProperty(QTextFormat::BackgroundBrush)) {
-                        backgroundBrushSet = true;
-                        backgroundBrush = fr.format.background();
-                    }
-
-                    break;
-                }
-
-                it.next();
-            }
-
-            // Draw selection or background color outside of areas where text is rendered
-            if (!m_printerFriendly) {
-                bool draw = false;
-                QBrush drawBrush;
-                if (m_view && m_view->selection() && !m_view->blockSelection() && m_view->lineEndSelected(line.end(true))) {
-                    draw = true;
-                    drawBrush = config()->selectionColor();
-                } else if (backgroundBrushSet && m_view && !m_view->blockSelection()) {
-                    draw = true;
-                    drawBrush = backgroundBrush;
-                }
-
-                if (draw) {
-                    int fillStartX = line.endX() - line.startX() + line.xOffset() - xStart;
-                    int fillStartY = lineHeight() * i;
-                    int width = xEnd - xStart - fillStartX;
-                    int height = lineHeight();
-
-                    // reverse X for right-aligned lines
-                    if (range->layout()->textOption().alignment() == Qt::AlignRight) {
-                        fillStartX = 0;
-                    }
-
-                    if (width > 0) {
-                        QRect area(fillStartX, fillStartY, width, height);
-                        paint.fillRect(area, drawBrush);
-                    }
-                }
-
-                // Draw indent lines
-                if (showIndentLines() && i == 0) {
-                    const qreal w = spaceWidth();
-                    const int lastIndentColumn = range->textLine()->indentDepth(m_tabWidth);
-
-                    for (int x = m_indentWidth; x < lastIndentColumn; x += m_indentWidth) {
-                        paintIndentMarker(paint, x * w + 1 - xStart, range->line());
-                    }
+            // Draw indent lines
+            if (!m_printerFriendly && (showIndentLines() && i == 0)) {
+                const qreal w = spaceWidth();
+                const int lastIndentColumn = range->textLine()->indentDepth(m_tabWidth);
+                for (int x = m_indentWidth; x < lastIndentColumn; x += m_indentWidth) {
+                    paintIndentMarker(paint, x * w + 1 - xStart, range->line());
                 }
             }
 
@@ -734,7 +663,8 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
             if (showNonPrintableSpaces()) {
                 const int y = lineHeight() * i + fm.ascent();
 
-                static const QRegularExpression nonPrintableSpacesRegExp(QStringLiteral("[\\x{2000}-\\x{200F}\\x{2028}-\\x{202F}\\x{205F}-\\x{2064}\\x{206A}-\\x{206F}]"));
+                static const QRegularExpression nonPrintableSpacesRegExp(
+                    QStringLiteral("[\\x{2000}-\\x{200F}\\x{2028}-\\x{202F}\\x{205F}-\\x{2064}\\x{206A}-\\x{206F}]"));
                 QRegularExpressionMatchIterator i = nonPrintableSpacesRegExp.globalMatch(text, line.lineLayout().xToCursor(xStart));
 
                 while (i.hasNext()) {
@@ -748,13 +678,18 @@ void KateRenderer::paintTextLine(QPainter &paint, KateLineLayoutPtr range, int x
                     paintNonPrintableSpaces(paint, x - xStart, y, text[charIndex]);
                 }
             }
-        }
 
-        // draw word-wrap-honor-indent filling
-        if ((range->viewLineCount() > 1) && range->shiftX() && (range->shiftX() > xStart)) {
-            if (backgroundBrushSet)
-                paint.fillRect(0, lineHeight(), range->shiftX() - xStart, lineHeight() * (range->viewLineCount() - 1), backgroundBrush);
-            paint.fillRect(0, lineHeight(), range->shiftX() - xStart, lineHeight() * (range->viewLineCount() - 1), QBrush(config()->wordWrapMarkerColor(), Qt::Dense4Pattern));
+            // draw word-wrap-honor-indent filling
+            if ((i > 0) && range->shiftX() && (range->shiftX() > xStart)) {
+                // fill background first with selection if we had selection from the previous line
+                if (drawSelection && !m_view->blockSelection() && m_view->selectionRange().start() < line.start()
+                    && m_view->selectionRange().end() >= line.start()) {
+                    paint.fillRect(0, lineHeight() * i, range->shiftX() - xStart, lineHeight(), QBrush(config()->selectionColor()));
+                }
+
+                // paint the normal filling for the word wrap markers
+                paint.fillRect(0, lineHeight() * i, range->shiftX() - xStart, lineHeight(), QBrush(config()->wordWrapMarkerColor(), Qt::Dense4Pattern));
+            }
         }
 
         // Draw caret
@@ -1060,7 +995,7 @@ void KateRenderer::layoutLine(KateLineLayoutPtr lineLayout, int maxwidth, bool c
 
     bool needShiftX = (maxwidth != -1) && m_view && (m_view->config()->dynWordWrapAlignIndent() > 0);
 
-    forever {
+    while (true) {
         QTextLine line = l->createLine();
         if (!line.isValid()) {
             break;
@@ -1177,6 +1112,10 @@ KTextEditor::Cursor KateRenderer::xToCursor(const KateTextLayout &range, int x,
     Q_ASSERT(range.isValid());
     KTextEditor::Cursor ret(range.line(), range.lineLayout().xToCursor(x));
 
+    // Do not wrap to the next line. (bug #423253)
+    if (range.wrap() && ret.column() >= range.endCol() && range.length() > 0) {
+        ret.setColumn(range.endCol() - 1);
+    }
     // TODO wrong for RTL lines?
     if (returnPastLine && range.endCol(true) == -1 && x > range.width() + range.xOffset()) {
         ret.setColumn(ret.column() + ((x - (range.width() + range.xOffset())) / spaceWidth()));
