@@ -85,7 +85,11 @@ public:
         m_menu->setEnabled(enabled);
     }
 
-    void addEntry(const QString &before, const QString &after, const QString &description, const QString &realBefore = QString(), const QString &realAfter = QString())
+    void addEntry(const QString &before,
+                  const QString &after,
+                  const QString &description,
+                  const QString &realBefore = QString(),
+                  const QString &realAfter = QString())
     {
         if (m_menu == nullptr) {
             return;
@@ -175,7 +179,9 @@ KateSearchBar::KateSearchBar(bool initAsPower, KTextEditor::ViewPrivate *view, K
     m_powerHighlightAll = (searchFlags & KateViewConfig::PowerHighlightAll) != 0;
     m_powerMode = ((searchFlags & KateViewConfig::PowerModeRegularExpression) != 0)
         ? MODE_REGEX
-        : (((searchFlags & KateViewConfig::PowerModeEscapeSequences) != 0) ? MODE_ESCAPE_SEQUENCES : (((searchFlags & KateViewConfig::PowerModeWholeWords) != 0) ? MODE_WHOLE_WORDS : MODE_PLAIN_TEXT));
+        : (((searchFlags & KateViewConfig::PowerModeEscapeSequences) != 0)
+               ? MODE_ESCAPE_SEQUENCES
+               : (((searchFlags & KateViewConfig::PowerModeWholeWords) != 0) ? MODE_WHOLE_WORDS : MODE_PLAIN_TEXT));
 
     // Load one of either dialogs
     if (initAsPower) {
@@ -211,6 +217,8 @@ void KateSearchBar::closed()
     }
 
     clearHighlights();
+    m_replacement.clear();
+    m_unfinishedSearchText.clear();
 }
 
 void KateSearchBar::setReplacementPattern(const QString &replacementPattern)
@@ -283,23 +291,6 @@ void KateSearchBar::showResultMessage()
     }
 }
 
-void KateSearchBar::showSearchWrappedHint(SearchDirection searchDirection)
-{
-    // show message widget when wrapping
-    const QIcon icon = (searchDirection == SearchForward) ? QIcon::fromTheme(QStringLiteral("go-down-search")) : QIcon::fromTheme(QStringLiteral("go-up-search"));
-
-    if (!m_wrappedMessage || m_lastSearchDirection != searchDirection) {
-        m_lastSearchDirection = searchDirection;
-        m_wrappedMessage = new KTextEditor::Message(i18n("Search wrapped"), KTextEditor::Message::Information);
-        m_wrappedMessage->setIcon(icon);
-        m_wrappedMessage->setPosition(KTextEditor::Message::BottomInView);
-        m_wrappedMessage->setAutoHide(2000);
-        m_wrappedMessage->setAutoHideMode(KTextEditor::Message::Immediate);
-        m_wrappedMessage->setView(m_view);
-        m_view->doc()->postMessage(m_wrappedMessage);
-    }
-}
-
 void KateSearchBar::highlightMatch(const Range &range)
 {
     KTextEditor::MovingRange *const highlight = m_view->doc()->newMovingRange(range, Kate::TextRange::DoNotExpand);
@@ -478,7 +469,7 @@ void KateSearchBar::onReturnPressed()
     }
 
     if (controlDown) {
-        emit hideMe();
+        Q_EMIT hideMe();
     }
 }
 
@@ -533,7 +524,8 @@ bool KateSearchBar::findOrReplace(SearchDirection searchDirection, const QString
             // Same match again
             if (replacement != nullptr) {
                 // Selection is match -> replace
-                KTextEditor::MovingRange *smartInputRange = m_view->doc()->newMovingRange(inputRange, KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
+                KTextEditor::MovingRange *smartInputRange =
+                    m_view->doc()->newMovingRange(inputRange, KTextEditor::MovingRange::ExpandLeft | KTextEditor::MovingRange::ExpandRight);
                 afterReplace = match.replace(*replacement, m_view->blockSelection());
                 inputRange = *smartInputRange;
                 delete smartInputRange;
@@ -578,11 +570,18 @@ bool KateSearchBar::findOrReplace(SearchDirection searchDirection, const QString
     }
 
     if (askWrap) {
-        QString question = searchDirection == SearchForward ? i18n("Bottom of file reached. Continue from top?") : i18n("Top of file reached. Continue from bottom?");
-        wrap = (KMessageBox::questionYesNo(nullptr, question, i18n("Continue search?"), KStandardGuiItem::yes(), KStandardGuiItem::no(), QStringLiteral("DoNotShowAgainContinueSearchDialog")) == KMessageBox::Yes);
+        QString question =
+            searchDirection == SearchForward ? i18n("Bottom of file reached. Continue from top?") : i18n("Top of file reached. Continue from bottom?");
+        wrap = (KMessageBox::questionYesNo(nullptr,
+                                           question,
+                                           i18n("Continue search?"),
+                                           KStandardGuiItem::yes(),
+                                           KStandardGuiItem::no(),
+                                           QStringLiteral("DoNotShowAgainContinueSearchDialog"))
+                == KMessageBox::Yes);
     }
     if (wrap) {
-        showSearchWrappedHint(searchDirection);
+        m_view->showSearchWrappedHint(searchDirection == SearchBackward);
         inputRange = m_view->document()->documentRange();
         match.searchText(inputRange, searchPattern());
     }
@@ -591,7 +590,8 @@ bool KateSearchBar::findOrReplace(SearchDirection searchDirection, const QString
         selectRange2(match.range());
     }
 
-    const MatchResult matchResult = !match.isValid() ? MatchMismatch : !wrap ? MatchFound : searchDirection == SearchForward ? MatchWrappedForward : MatchWrappedBackward;
+    const MatchResult matchResult =
+        !match.isValid() ? MatchMismatch : !wrap ? MatchFound : searchDirection == SearchForward ? MatchWrappedForward : MatchWrappedBackward;
     indicateMatch(matchResult);
 
     // highlight replacements if applicable
@@ -627,7 +627,9 @@ bool KateSearchBar::isPatternValid() const
         return false;
     }
 
-    return searchOptions().testFlag(WholeWords) ? searchPattern().trimmed() == searchPattern() : searchOptions().testFlag(Regex) ? QRegularExpression(searchPattern()).isValid() : true;
+    return searchOptions().testFlag(WholeWords) ? searchPattern().trimmed() == searchPattern()
+                                                : searchOptions().testFlag(Regex)
+                                                ? QRegularExpression(searchPattern(), QRegularExpression::UseUnicodePropertiesOption).isValid() : true;
 }
 
 void KateSearchBar::givePatternFeedback()
@@ -679,21 +681,25 @@ void KateSearchBar::sendConfig()
         // Update power search flags only
         const auto incFlagsOnly = pastFlags & (KateViewConfig::IncHighlightAll | KateViewConfig::IncFromCursor | KateViewConfig::IncMatchCase);
 
-        futureFlags = incFlagsOnly | (m_powerMatchCase ? KateViewConfig::PowerMatchCase : 0) | (m_powerFromCursor ? KateViewConfig::PowerFromCursor : 0) | (m_powerHighlightAll ? KateViewConfig::PowerHighlightAll : 0) |
-            ((m_powerMode == MODE_REGEX)
-                 ? KateViewConfig::PowerModeRegularExpression
-                 : ((m_powerMode == MODE_ESCAPE_SEQUENCES) ? KateViewConfig::PowerModeEscapeSequences : ((m_powerMode == MODE_WHOLE_WORDS) ? KateViewConfig::PowerModeWholeWords : KateViewConfig::PowerModePlainText)));
+        futureFlags = incFlagsOnly | (m_powerMatchCase ? KateViewConfig::PowerMatchCase : 0) | (m_powerFromCursor ? KateViewConfig::PowerFromCursor : 0)
+            | (m_powerHighlightAll ? KateViewConfig::PowerHighlightAll : 0)
+            | ((m_powerMode == MODE_REGEX)
+                   ? KateViewConfig::PowerModeRegularExpression
+                   : ((m_powerMode == MODE_ESCAPE_SEQUENCES)
+                          ? KateViewConfig::PowerModeEscapeSequences
+                          : ((m_powerMode == MODE_WHOLE_WORDS) ? KateViewConfig::PowerModeWholeWords : KateViewConfig::PowerModePlainText)));
 
     } else if (m_incUi != nullptr) {
         const bool OF_INCREMENTAL = false;
         backupConfig(OF_INCREMENTAL);
 
         // Update incremental search flags only
-        const auto powerFlagsOnly = pastFlags &
-            (KateViewConfig::PowerMatchCase | KateViewConfig::PowerFromCursor | KateViewConfig::PowerHighlightAll | KateViewConfig::PowerModeRegularExpression | KateViewConfig::PowerModeEscapeSequences |
-             KateViewConfig::PowerModeWholeWords | KateViewConfig::PowerModePlainText);
+        const auto powerFlagsOnly = pastFlags
+            & (KateViewConfig::PowerMatchCase | KateViewConfig::PowerFromCursor | KateViewConfig::PowerHighlightAll | KateViewConfig::PowerModeRegularExpression
+               | KateViewConfig::PowerModeEscapeSequences | KateViewConfig::PowerModeWholeWords | KateViewConfig::PowerModePlainText);
 
-        futureFlags = powerFlagsOnly | (m_incHighlightAll ? KateViewConfig::IncHighlightAll : 0) | (m_incFromCursor ? KateViewConfig::IncFromCursor : 0) | (m_incMatchCase ? KateViewConfig::IncMatchCase : 0);
+        futureFlags = powerFlagsOnly | (m_incHighlightAll ? KateViewConfig::IncHighlightAll : 0) | (m_incFromCursor ? KateViewConfig::IncFromCursor : 0)
+            | (m_incMatchCase ? KateViewConfig::IncMatchCase : 0);
     }
 
     // Adjust global config
@@ -827,7 +833,7 @@ void KateSearchBar::findOrReplaceAll()
     } while (!m_cancelFindOrReplace && !timeOut && block && ++line <= m_inputRange.end().line());
 
     if (done || m_cancelFindOrReplace) {
-        emit findOrReplaceAllFinished();
+        Q_EMIT findOrReplaceAllFinished();
     } else if (timeOut) {
         QTimer::singleShot(0, this, &KateSearchBar::findOrReplaceAll);
     }
@@ -1096,7 +1102,11 @@ void KateSearchBar::showExtendedContextMenu(bool forPattern, const QPoint &pos)
                 addMenuManager.addEntry(QStringLiteral("+"), QString(), i18n("One or more occurrences"));
                 addMenuManager.addEntry(QStringLiteral("*"), QString(), i18n("Zero or more occurrences"));
                 addMenuManager.addEntry(QStringLiteral("?"), QString(), i18n("Zero or one occurrences"));
-                addMenuManager.addEntry(QStringLiteral("{a"), QStringLiteral(",b}"), i18n("<a> through <b> occurrences"), QStringLiteral("{"), QStringLiteral(",}"));
+                addMenuManager.addEntry(QStringLiteral("{a"),
+                                        QStringLiteral(",b}"),
+                                        i18n("<a> through <b> occurrences"),
+                                        QStringLiteral("{"),
+                                        QStringLiteral(",}"));
 
                 addMenuManager.addSeparator();
                 addMenuManager.addSeparator();
@@ -1116,7 +1126,8 @@ void KateSearchBar::showExtendedContextMenu(bool forPattern, const QPoint &pos)
                 const int captureCount = capturePatterns.count();
                 for (int i = 1; i <= 9; i++) {
                     const QString number = QString::number(i);
-                    const QString &captureDetails = (i <= captureCount) ? QLatin1String(" = (") + capturePatterns[i - 1].leftRef(30) + QLatin1Char(')') : QString();
+                    const QString &captureDetails =
+                        (i <= captureCount) ? QLatin1String(" = (") + capturePatterns[i - 1].leftRef(30) + QLatin1Char(')') : QString();
                     addMenuManager.addEntry(QLatin1String("\\") + number, QString(), i18n("Reference") + QLatin1Char(' ') + number + captureDetails);
                 }
 
@@ -1221,7 +1232,7 @@ void KateSearchBar::nextMatchForSelection(KTextEditor::ViewPrivate *view, Search
             selectRange(view, match.range());
         } else {
             // Find, second try
-            showSearchWrappedHint(searchDirection);
+            m_view->showSearchWrappedHint(searchDirection == SearchBackward);
             if (searchDirection == SearchForward) {
                 inputRange.setRange(Cursor(0, 0), selRange.start());
             } else {
@@ -1270,6 +1281,9 @@ void KateSearchBar::enterPowerMode()
         const bool fromIncremental = (m_incUi != nullptr) && (m_widget->isVisible());
         if (fromIncremental) {
             initialPattern = m_incUi->pattern->currentText();
+        } else {
+            // Search bar probably newly opened. Reset initial replacement text to empty
+            m_replacement.clear();
         }
     }
 
@@ -1309,6 +1323,10 @@ void KateSearchBar::enterPowerMode()
         m_powerUi->replacement->lineEdit()->setClearButtonEnabled(true);
         m_powerUi->replacement->setCompleter(nullptr);
 
+        // Filter Up/Down arrow key inputs to save unfinished search/replace text
+        m_powerUi->pattern->installEventFilter(this);
+        m_powerUi->replacement->installEventFilter(this);
+
         // Icons
         // Gnome does not seem to have all icons we want, so we use fall-back icons for those that are missing.
         QIcon mutateIcon = QIcon::fromTheme(QStringLiteral("games-config-options"), QIcon::fromTheme(QStringLiteral("preferences-system")));
@@ -1346,7 +1364,7 @@ void KateSearchBar::enterPowerMode()
     // Set initial replacement text
     QLineEdit *const replacementLineEdit = m_powerUi->replacement->lineEdit();
     Q_ASSERT(replacementLineEdit != nullptr);
-    replacementLineEdit->setText(QString());
+    replacementLineEdit->setText(m_replacement);
 
     // Propagate settings (slots are still inactive on purpose)
     onPowerPatternChanged(initialPattern);
@@ -1354,26 +1372,33 @@ void KateSearchBar::enterPowerMode()
 
     if (create) {
         // Slots
-        connect(m_powerUi->mutate, SIGNAL(clicked()), this, SLOT(enterIncrementalMode()));
-        connect(patternLineEdit, SIGNAL(textChanged(QString)), this, SLOT(onPowerPatternChanged(QString)));
-        connect(m_powerUi->findNext, SIGNAL(clicked()), this, SLOT(findNext()));
-        connect(m_powerUi->findPrev, SIGNAL(clicked()), this, SLOT(findPrevious()));
-        connect(m_powerUi->replaceNext, SIGNAL(clicked()), this, SLOT(replaceNext()));
-        connect(m_powerUi->replaceAll, SIGNAL(clicked()), this, SLOT(replaceAll()));
-        connect(m_powerUi->searchMode, SIGNAL(currentIndexChanged(int)), this, SLOT(onPowerModeChanged(int)));
-        connect(m_powerUi->matchCase, SIGNAL(toggled(bool)), this, SLOT(onMatchCaseToggled(bool)));
-        connect(m_powerUi->findAll, SIGNAL(clicked()), this, SLOT(findAll()));
+        connect(m_powerUi->mutate, &QToolButton::clicked, this, &KateSearchBar::enterIncrementalMode);
+        connect(patternLineEdit, &QLineEdit::textChanged, this, &KateSearchBar::onPowerPatternChanged);
+        connect(m_powerUi->findNext, &QToolButton::clicked, this, &KateSearchBar::findNext);
+        connect(m_powerUi->findPrev, &QToolButton::clicked, this, &KateSearchBar::findPrevious);
+        connect(m_powerUi->replaceNext, &QPushButton::clicked, this, &KateSearchBar::replaceNext);
+        connect(m_powerUi->replaceAll, &QPushButton::clicked, this, &KateSearchBar::replaceAll);
+        connect(m_powerUi->searchMode, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &KateSearchBar::onPowerModeChanged);
+        connect(m_powerUi->matchCase, &QToolButton::toggled, this, &KateSearchBar::onMatchCaseToggled);
+        connect(m_powerUi->findAll, &QPushButton::clicked, this, &KateSearchBar::findAll);
         connect(m_powerUi->cancel, &QPushButton::clicked, this, &KateSearchBar::onPowerCancelFindOrReplace);
 
         // Make [return] in pattern line edit trigger <find next> action
-        connect(patternLineEdit, SIGNAL(returnPressed()), this, SLOT(onReturnPressed()));
-        connect(replacementLineEdit, SIGNAL(returnPressed()), this, SLOT(replaceNext()));
+        connect(patternLineEdit, &QLineEdit::returnPressed, this, &KateSearchBar::onReturnPressed);
+        connect(replacementLineEdit, &QLineEdit::returnPressed, this, &KateSearchBar::replaceNext);
 
         // Hook into line edit context menus
         m_powerUi->pattern->setContextMenuPolicy(Qt::CustomContextMenu);
-        connect(m_powerUi->pattern, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(onPowerPatternContextMenuRequest(QPoint)));
+
+        connect(m_powerUi->pattern,
+                &QComboBox::customContextMenuRequested,
+                this,
+                QOverload<const QPoint &>::of(&KateSearchBar::onPowerPatternContextMenuRequest));
         m_powerUi->replacement->setContextMenuPolicy(Qt::CustomContextMenu);
-        connect(m_powerUi->replacement, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(onPowerReplacmentContextMenuRequest(QPoint)));
+        connect(m_powerUi->replacement,
+                &QComboBox::customContextMenuRequested,
+                this,
+                QOverload<const QPoint &>::of(&KateSearchBar::onPowerReplacmentContextMenuRequest));
     }
 
     // Focus
@@ -1410,6 +1435,8 @@ void KateSearchBar::enterIncrementalMode()
         const bool fromReplace = (m_powerUi != nullptr) && (m_widget->isVisible());
         if (fromReplace) {
             initialPattern = m_powerUi->pattern->currentText();
+            // current text will be used as initial replacement text later
+            m_replacement = m_powerUi->replacement->currentText();
         }
     }
 
@@ -1441,6 +1468,9 @@ void KateSearchBar::enterIncrementalMode()
         m_incUi->setupUi(m_widget);
         m_layout->addWidget(m_widget);
 
+        // Filter Up/Down arrow key inputs to save unfinished search text
+        m_incUi->pattern->installEventFilter(this);
+
         //         new QShortcut(KStandardShortcut::paste().primary(), m_incUi->pattern, SLOT(paste()), 0, Qt::WidgetWithChildrenShortcut);
         //         if (!KStandardShortcut::paste().alternate().isEmpty())
         //             new QShortcut(KStandardShortcut::paste().alternate(), m_incUi->pattern, SLOT(paste()), 0, Qt::WidgetWithChildrenShortcut);
@@ -1481,10 +1511,10 @@ void KateSearchBar::enterIncrementalMode()
 
     // Set initial search pattern
     if (!create) {
-        disconnect(m_incUi->pattern, SIGNAL(editTextChanged(QString)), this, SLOT(onIncPatternChanged(QString)));
+        disconnect(m_incUi->pattern, &QComboBox::editTextChanged, this, &KateSearchBar::onIncPatternChanged);
     }
     m_incUi->pattern->setEditText(initialPattern);
-    connect(m_incUi->pattern, SIGNAL(editTextChanged(QString)), this, SLOT(onIncPatternChanged(QString)));
+    connect(m_incUi->pattern, &QComboBox::editTextChanged, this, &KateSearchBar::onIncPatternChanged);
     m_incUi->pattern->lineEdit()->selectAll();
 
     // Propagate settings (slots are still inactive on purpose)
@@ -1499,11 +1529,11 @@ void KateSearchBar::enterIncrementalMode()
 
     if (create) {
         // Slots
-        connect(m_incUi->mutate, SIGNAL(clicked()), this, SLOT(enterPowerMode()));
-        connect(m_incUi->pattern->lineEdit(), SIGNAL(returnPressed()), this, SLOT(onReturnPressed()));
-        connect(m_incUi->next, SIGNAL(clicked()), this, SLOT(findNext()));
-        connect(m_incUi->prev, SIGNAL(clicked()), this, SLOT(findPrevious()));
-        connect(m_incUi->matchCase, SIGNAL(toggled(bool)), this, SLOT(onMatchCaseToggled(bool)));
+        connect(m_incUi->mutate, &QToolButton::clicked, this, &KateSearchBar::enterPowerMode);
+        connect(m_incUi->pattern->lineEdit(), &QLineEdit::returnPressed, this, &KateSearchBar::onReturnPressed);
+        connect(m_incUi->next, &QToolButton::clicked, this, &KateSearchBar::findNext);
+        connect(m_incUi->prev, &QToolButton::clicked, this, &KateSearchBar::findPrevious);
+        connect(m_incUi->matchCase, &QToolButton::toggled, this, &KateSearchBar::onMatchCaseToggled);
     }
 
     // Focus
@@ -1569,6 +1599,30 @@ void KateSearchBar::showEvent(QShowEvent *event)
     KateViewBarWidget::showEvent(event);
 }
 
+bool KateSearchBar::eventFilter(QObject *obj, QEvent *event)
+{
+    QComboBox *combo = qobject_cast<QComboBox *>(obj);
+    if (combo && event->type() == QEvent::KeyPress) {
+        const int key = static_cast<QKeyEvent *>(event)->key();
+        const int currentIndex = combo->currentIndex();
+        const QString currentText = combo->currentText();
+        QString &unfinishedText = (m_powerUi && combo == m_powerUi->replacement) ? m_replacement : m_unfinishedSearchText;
+        if (key == Qt::Key_Up && currentIndex <= 0 && unfinishedText != currentText) {
+            // Only restore unfinished text if we are already in the latest entry
+            combo->setCurrentIndex(-1);
+            combo->setCurrentText(unfinishedText);
+        } else if (key == Qt::Key_Down || key == Qt::Key_Up) {
+            // Only save unfinished text if it is not empty and it is modified
+            const bool isUnfinishedSearch = (!currentText.trimmed().isEmpty() && (currentIndex == -1 || combo->itemText(currentIndex) != currentText));
+            if (isUnfinishedSearch && unfinishedText != currentText) {
+                unfinishedText = currentText;
+            }
+        }
+    }
+
+    return QWidget::eventFilter(obj, event);
+}
+
 void KateSearchBar::updateSelectionOnly()
 {
     if (m_powerUi == nullptr) {
