@@ -11,12 +11,13 @@
 #include "katedocument.h"
 #include "kateglobal.h"
 #include "katemodemanager.h"
+#include "katemodemenulist.h"
+#include "kateview.h"
 #include "wordcounter.h"
 
 #include <KAcceleratorManager>
 #include <KActionCollection>
 #include <KIconUtils>
-#include <KLocalizedString>
 #include <Sonnet/Speller>
 
 #include <QHBoxLayout>
@@ -94,13 +95,17 @@ KateStatusBar::KateStatusBar(KTextEditor::ViewPrivate *view)
     // show the zoom level of the text
     m_zoomLevel = new StatusBarButton(this);
     topLayout->addWidget(m_zoomLevel);
-    connect(m_zoomLevel, &StatusBarButton::clicked, [=] { m_view->renderer()->resetFontSizes(); });
+    connect(m_zoomLevel, &StatusBarButton::clicked, [=] {
+        m_view->renderer()->resetFontSizes();
+    });
 
     // show the current mode, like INSERT, OVERWRITE, VI + modifiers like [BLOCK]
     m_inputMode = new StatusBarButton(this);
     topLayout->addWidget(m_inputMode);
     m_inputMode->setWhatsThis(i18n("Insert mode and VI input mode indicator. Click to change the mode."));
-    connect(m_inputMode, &StatusBarButton::clicked, [=] { m_view->currentInputMode()->toggleInsert(); });
+    connect(m_inputMode, &StatusBarButton::clicked, [=] {
+        m_view->currentInputMode()->toggleInsert();
+    });
 
     // Add dictionary button which allows user to switch dictionary of the document
     m_dictionary = new StatusBarButton(this);
@@ -172,7 +177,8 @@ KateStatusBar::KateStatusBar(KTextEditor::ViewPrivate *view)
     // load the mode menu, which contains a scrollable list + search bar.
     // This is an alternative menu to the mode action menu of the view.
     m_modeMenuList = new KateModeMenuList(i18n("Mode"), this);
-    m_modeMenuList->setWhatsThis(i18n("Here you can choose which mode should be used for the current document. This will influence the highlighting and folding being used, for example."));
+    m_modeMenuList->setWhatsThis(i18n(
+        "Here you can choose which mode should be used for the current document. This will influence the highlighting and folding being used, for example."));
     m_modeMenuList->updateMenu(m_view->doc());
     // add mode button which allows user to switch mode of document
     m_mode = new StatusBarButton(this);
@@ -188,9 +194,9 @@ KateStatusBar::KateStatusBar(KTextEditor::ViewPrivate *view)
     connect(m_view->document(), &KTextEditor::DocumentPrivate::modifiedChanged, this, &KateStatusBar::modifiedChanged);
     connect(m_view->doc(), &KTextEditor::DocumentPrivate::modifiedOnDisk, this, &KateStatusBar::modifiedChanged);
     connect(m_view->doc(), &KTextEditor::DocumentPrivate::readWriteChanged, this, &KateStatusBar::modifiedChanged);
-    connect(m_view->doc(), &KTextEditor::DocumentPrivate::configChanged, this, &KateStatusBar::documentConfigChanged);
+    connect(m_view->doc(), &KTextEditor::Document::configChanged, this, &KateStatusBar::documentConfigChanged);
     connect(m_view->document(), &KTextEditor::DocumentPrivate::modeChanged, this, &KateStatusBar::modeChanged);
-    connect(m_view, &KTextEditor::ViewPrivate::configChanged, this, &KateStatusBar::configChanged);
+    connect(m_view, &KTextEditor::View::configChanged, this, &KateStatusBar::configChanged);
     connect(m_view->doc(), &KTextEditor::DocumentPrivate::defaultDictionaryChanged, this, &KateStatusBar::updateDictionary);
     connect(m_view->doc(), &KTextEditor::DocumentPrivate::dictionaryRangesPresent, this, &KateStatusBar::updateDictionary);
     connect(m_view, &KTextEditor::ViewPrivate::caretChangedRange, this, &KateStatusBar::updateDictionary);
@@ -280,7 +286,10 @@ void KateStatusBar::cursorPositionChanged()
     // Update line/column label
     QString text;
     if (KateViewConfig::global()->showLineCount()) {
-        text = i18n("Line %1 of %2, Column %3", QLocale().toString(position.line() + 1), QLocale().toString(m_view->doc()->lines()), QLocale().toString(position.column() + 1));
+        text = i18n("Line %1 of %2, Column %3",
+                    QLocale().toString(position.line() + 1),
+                    QLocale().toString(m_view->doc()->lines()),
+                    QLocale().toString(position.column() + 1));
     } else {
         text = i18n("Line %1, Column %2", QLocale().toString(position.line() + 1), QLocale().toString(position.column() + 1));
     }
@@ -369,7 +378,8 @@ void KateStatusBar::modifiedChanged()
 
     case 0x3:
     case 0x7:
-        m_modified->setIcon(QIcon(KIconUtils::addOverlay(QIcon::fromTheme(QStringLiteral("document-save")), QIcon(QStringLiteral("emblem-important")), Qt::TopLeftCorner)));
+        m_modified->setIcon(
+            QIcon(KIconUtils::addOverlay(QIcon::fromTheme(QStringLiteral("document-save")), QIcon(QStringLiteral("emblem-important")), Qt::TopLeftCorner)));
         m_modified->setWhatsThis(QString());
         break;
 
@@ -451,11 +461,14 @@ void KateStatusBar::updateGroup(QActionGroup *group, int w)
             action->setChecked(true);
         }
     }
-    if (found) {
-        m1->setText(i18n("Other..."));
-    } else {
-        m1->setText(i18np("Other (%1)", "Other (%1)", w));
-        m1->setChecked(true);
+
+    if (m1) {
+        if (found) {
+            m1->setText(i18n("Other..."));
+        } else {
+            m1->setText(i18np("Other (%1)", "Other (%1)", w));
+            m1->setChecked(true);
+        }
     }
 }
 
@@ -465,7 +478,7 @@ void KateStatusBar::slotTabGroup(QAction *a)
     bool ok;
     KateDocumentConfig *config = ((KTextEditor::DocumentPrivate *)m_view->document())->config();
     if (val == -1) {
-        val = QInputDialog::getInt(this, i18n("Tab Width"), i18n("Please specify the wanted tab width:"), config->tabWidth(), 1, 16, 1, &ok);
+        val = QInputDialog::getInt(this, i18n("Tab Width"), i18n("Please specify the wanted tab width:"), config->tabWidth(), 1, 200, 1, &ok);
         if (!ok)
             val = config->tabWidth();
     }
@@ -478,7 +491,14 @@ void KateStatusBar::slotIndentGroup(QAction *a)
     bool ok;
     KateDocumentConfig *config = ((KTextEditor::DocumentPrivate *)m_view->document())->config();
     if (val == -1) {
-        val = QInputDialog::getInt(this, i18n("Indentation Width"), i18n("Please specify the wanted indentation width:"), config->indentationWidth(), 1, 16, 1, &ok);
+        val = QInputDialog::getInt(this,
+                                   i18n("Indentation Width"),
+                                   i18n("Please specify the wanted indentation width:"),
+                                   config->indentationWidth(),
+                                   1,
+                                   200,
+                                   1,
+                                   &ok);
         if (!ok)
             val = config->indentationWidth();
     }
@@ -531,7 +551,12 @@ void KateStatusBar::toggleWordCount(bool on)
 void KateStatusBar::wordCountChanged(int wordsInDocument, int wordsInSelection, int charsInDocument, int charsInSelection)
 {
     if (m_wordCounter) {
-        m_wordCount = i18nc("%1 and %3 are the selected words/chars count, %2 and %4 are the total words/chars count.", "Words %1/%2, Chars %3/%4", wordsInSelection, wordsInDocument, charsInSelection, charsInDocument);
+        m_wordCount = i18nc("%1 and %3 are the selected words/chars count, %2 and %4 are the total words/chars count.",
+                            "Words %1/%2, Chars %3/%4",
+                            wordsInSelection,
+                            wordsInDocument,
+                            charsInSelection,
+                            charsInDocument);
     } else {
         m_wordCount.clear();
     }
