@@ -14,20 +14,21 @@
 #include <ktexteditor/codecompletioninterface.h>
 #include <ktexteditor/configinterface.h>
 #include <ktexteditor/inlinenoteinterface.h>
+#include <ktexteditor/linerange.h>
 #include <ktexteditor/mainwindow.h>
-#include <ktexteditor/markinterface.h>
 #include <ktexteditor/texthintinterface.h>
 #include <ktexteditor/view.h>
 
+#include <QJsonDocument>
 #include <QMenu>
 #include <QModelIndex>
 #include <QPointer>
 #include <QScopedPointer>
 #include <QSpacerItem>
+#include <QTextLayout>
 
 #include <array>
 
-#include "katerenderer.h"
 #include "katetextfolding.h"
 #include "katetextrange.h"
 
@@ -200,9 +201,6 @@ public:
     QVariant configValue(const QString &key) override;
     void setConfigValue(const QString &key, const QVariant &value) override;
 
-Q_SIGNALS:
-    void configChanged();
-
 public:
     /**
      * Try to fold an unfolded range starting at @p line
@@ -371,7 +369,7 @@ public:
     bool tagLine(const KTextEditor::Cursor &virtualCursor);
 
     bool tagRange(const KTextEditor::Range &range, bool realLines = false);
-    bool tagLines(int start, int end, bool realLines = false);
+    bool tagLines(KTextEditor::LineRange lineRange, bool realLines = false);
     bool tagLines(KTextEditor::Cursor start, KTextEditor::Cursor end, bool realCursors = false);
     bool tagLines(KTextEditor::Range range, bool realRange = false);
 
@@ -419,27 +417,27 @@ private:
 public:
     void emitNavigateLeft()
     {
-        emit navigateLeft();
+        Q_EMIT navigateLeft();
     }
     void emitNavigateRight()
     {
-        emit navigateRight();
+        Q_EMIT navigateRight();
     }
     void emitNavigateUp()
     {
-        emit navigateUp();
+        Q_EMIT navigateUp();
     }
     void emitNavigateDown()
     {
-        emit navigateDown();
+        Q_EMIT navigateDown();
     }
     void emitNavigateAccept()
     {
-        emit navigateAccept();
+        Q_EMIT navigateAccept();
     }
     void emitNavigateBack()
     {
-        emit navigateBack();
+        Q_EMIT navigateBack();
     }
     /**
      Return values for "save" related commands.
@@ -627,6 +625,7 @@ public Q_SLOTS:
     void replace();
     void findNext();
     void findPrevious();
+    void showSearchWrappedHint(bool isReverseSearch);
 
     void setFoldingMarkersOn(bool enable); // Not in KTextEditor::View, but should be
     void setIconBorder(bool enable);
@@ -904,11 +903,10 @@ private:
 public:
     /**
      * Attribute of a range changed or range with attribute changed in given line range.
-     * @param startLine start line of change
-     * @param endLine end line of change
+     * @param lineRange line range that the change spans
      * @param rangeWithAttribute attribute changed or is active, this will perhaps lead to repaints
      */
-    void notifyAboutRangeChange(int startLine, int endLine, bool rangeWithAttribute);
+    void notifyAboutRangeChange(KTextEditor::LineRange lineRange, bool rangeWithAttribute);
 
 private Q_SLOTS:
     /**
@@ -963,14 +961,9 @@ private:
     bool m_delayedUpdateTriggered;
 
     /**
-     * minimal line to update
+     * line range to update
      */
-    int m_lineToUpdateMin;
-
-    /**
-     * maximal line to update
-     */
-    int m_lineToUpdateMax;
+    KTextEditor::LineRange m_lineToUpdateRange;
 
     /**
      * set of ranges which had the mouse inside last time
@@ -1109,6 +1102,10 @@ private:
      * manage sub objects on its own that have this view as parent
      */
     QScopedPointer<KateScriptActionMenu> m_scriptActionMenu;
+
+    // for showSearchWrappedHint()
+    QPointer<KTextEditor::Message> m_wrappedMessage;
+    bool m_isLastSearchReversed = false;
 };
 
 }
