@@ -1,21 +1,7 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2013-2016 Simon St James <kdedevel@etotheipiplusone.com>
 
-    Copyright (C) 2013-2016 Simon St James <kdedevel@etotheipiplusone.com>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "completer.h"
@@ -23,6 +9,7 @@
 
 using namespace KateVi;
 
+#include "activemode.h"
 #include "kateview.h"
 
 #include <QAbstractItemView>
@@ -193,7 +180,8 @@ void Completer::currentCompletionChanged()
 
 void Completer::updateCompletionPrefix()
 {
-    const QString completionPrefix = m_edit->text().mid(m_currentCompletionStartParams.wordStartPos, m_edit->cursorPosition() - m_currentCompletionStartParams.wordStartPos);
+    const QString completionPrefix =
+        m_edit->text().mid(m_currentCompletionStartParams.wordStartPos, m_edit->cursorPosition() - m_currentCompletionStartParams.wordStartPos);
     m_completer->setCompletionPrefix(completionPrefix);
     // Seem to need a call to complete() else the size of the popup box is not altered appropriately.
     m_completer->complete();
@@ -201,7 +189,7 @@ void Completer::updateCompletionPrefix()
 
 CompletionStartParams Completer::activateWordFromDocumentCompletion()
 {
-    static const QRegularExpression wordRegEx(QStringLiteral("\\w{1,}"));
+    static const QRegularExpression wordRegEx(QStringLiteral("\\w+"), QRegularExpression::UseUnicodePropertiesOption);
     QRegularExpressionMatch match;
 
     QStringList foundWords;
@@ -217,7 +205,7 @@ CompletionStartParams Completer::activateWordFromDocumentCompletion()
             wordSearchBeginPos = match.capturedEnd();
         }
     }
-    foundWords = QSet<QString>::fromList(foundWords).values();
+    foundWords.removeDuplicates();
     std::sort(foundWords.begin(), foundWords.end(), caseInsensitiveLessThan);
     CompletionStartParams completionStartParams;
     completionStartParams.completionType = CompletionStartParams::WordFromDocument;
@@ -235,7 +223,8 @@ QString Completer::wordBeforeCursor()
 int Completer::wordBeforeCursorBegin()
 {
     int wordBeforeCursorBegin = m_edit->cursorPosition() - 1;
-    while (wordBeforeCursorBegin >= 0 && (m_edit->text()[wordBeforeCursorBegin].isLetterOrNumber() || m_edit->text()[wordBeforeCursorBegin] == QLatin1Char('_'))) {
+    while (wordBeforeCursorBegin >= 0
+           && (m_edit->text()[wordBeforeCursorBegin].isLetterOrNumber() || m_edit->text()[wordBeforeCursorBegin] == QLatin1Char('_'))) {
         wordBeforeCursorBegin--;
     }
     wordBeforeCursorBegin++;
